@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -348,7 +348,7 @@ get_markup_token (const gchar *alltext, const gchar *start, gint *out_nb_spaces_
 	return MARKUP_NONE;
 }
 
-/**
+/*
  * steals @base64
  */
 static gchar *
@@ -917,12 +917,7 @@ rt_parse_text (const gchar *text)
 			else {
 				gchar *tmp;
 				tmp = remove_newlines_from_base64 (part);
-#if GLIB_CHECK_VERSION(2,20,0)
 				node->binary.data = g_base64_decode_inplace (tmp, (gsize*) & node->binary.binary_length);
-#else
-				node->binary.data = g_base64_decode (tmp, (gsize*) & node->binary.binary_length);
-				g_free (tmp);
-#endif
 			}
 		}
 		else {
