@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -61,7 +62,6 @@ static GtkWidget *create_entry (GdauiEntryWrapper *mgwrap);
 static void       real_set_value (GdauiEntryWrapper *mgwrap, const GValue *value);
 static GValue    *real_get_value (GdauiEntryWrapper *mgwrap);
 static void       connect_signals(GdauiEntryWrapper *mgwrap, GCallback modify_cb, GCallback activate_cb);
-static gboolean   can_expand (GdauiEntryWrapper *mgwrap, gboolean horiz);
 static void       set_editable (GdauiEntryWrapper *mgwrap, gboolean editable);
 static void       grab_focus (GdauiEntryWrapper *mgwrap);
 
@@ -141,7 +141,6 @@ gdaui_entry_string_class_init (GdauiEntryStringClass * klass)
 	GDAUI_ENTRY_WRAPPER_CLASS (klass)->real_set_value = real_set_value;
 	GDAUI_ENTRY_WRAPPER_CLASS (klass)->real_get_value = real_get_value;
 	GDAUI_ENTRY_WRAPPER_CLASS (klass)->connect_signals = connect_signals;
-	GDAUI_ENTRY_WRAPPER_CLASS (klass)->can_expand = can_expand;
 	GDAUI_ENTRY_WRAPPER_CLASS (klass)->set_editable = set_editable;
 	GDAUI_ENTRY_WRAPPER_CLASS (klass)->grab_focus = grab_focus;
 
@@ -272,10 +271,12 @@ gdaui_entry_string_set_property (GObject *object,
 				if (mgstr->priv->multiline) {
 					gtk_widget_hide (mgstr->priv->entry);
 					gtk_widget_show (mgstr->priv->sw);
+					gtk_widget_set_vexpand (GTK_WIDGET (mgstr), TRUE);
 				}
 				else {
 					gtk_widget_show (mgstr->priv->entry);
 					gtk_widget_hide (mgstr->priv->sw);
+					gtk_widget_set_vexpand (GTK_WIDGET (mgstr), FALSE);
 				}
 				g_signal_emit_by_name (object, "expand-changed");
 			}
@@ -329,7 +330,7 @@ create_entry (GdauiEntryWrapper *mgwrap)
 	mgstr = GDAUI_ENTRY_STRING (mgwrap);
 	g_return_val_if_fail (mgstr->priv, NULL);
 
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	mgstr->priv->vbox = vbox;
 
 	/* one line entry */
@@ -473,21 +474,6 @@ connect_signals(GdauiEntryWrapper *mgwrap, GCallback modify_cb, GCallback activa
 	/* FIXME: how does the user "activates" the GtkTextView widget ? */
 }
 
-static gboolean
-can_expand (GdauiEntryWrapper *mgwrap, gboolean horiz)
-{
-	GdauiEntryString *mgstr;
-
-	g_return_val_if_fail (GDAUI_IS_ENTRY_STRING (mgwrap), FALSE);
-	mgstr = GDAUI_ENTRY_STRING (mgwrap);
-	g_return_val_if_fail (mgstr->priv, FALSE);
-
-	if (horiz)
-		return FALSE;
-	else
-		return mgstr->priv->multiline;
-}
-
 static void
 set_editable (GdauiEntryWrapper *mgwrap, gboolean editable)
 {
