@@ -84,7 +84,9 @@ gda_server_provider_perform_operation_default (GdaServerProvider *provider, GdaC
 	if (!sql)
 		return FALSE;
 
-	batch = gda_sql_parser_parse_string_as_batch (provider->priv->parser, sql, NULL, error);
+	GdaSqlParser *parser;
+	parser = gda_server_provider_internal_get_parser (provider); /* no ref held! */
+	batch = gda_sql_parser_parse_string_as_batch (parser, sql, NULL, error);
 	g_free (sql);
 	if (!batch)
 		return FALSE;
@@ -97,25 +99,26 @@ gda_server_provider_perform_operation_default (GdaServerProvider *provider, GdaC
 	}
 	g_object_unref (batch);
 
-	return retval;;
+	return retval;
 }
 
 /**
- * gda_server_provider_get_data_handler_default:
- * @provider: a server provider.
- * @cnc: (allow-none): a #GdaConnection object, or %NULL
+ * gda_server_provider_handler_use_default: (skip)
+ * @provider: a server provider
  * @type: a #GType
- * @dbms_type: a DBMS type definition
  *
- * Provides the implementation when the default Libgda's data handlers must be used
- * 
+ * Reserved to database provider's implementations. This method defines a default data handler for
+ * @provider, and returns that #GdaDataHandler.
+ *
  * Returns: (transfer none): a #GdaDataHandler, or %NULL
+ *
+ * Since: 5.2
  */
 GdaDataHandler *
-gda_server_provider_get_data_handler_default (GdaServerProvider *provider, G_GNUC_UNUSED GdaConnection *cnc,
-					      GType type, G_GNUC_UNUSED const gchar *dbms_type)
+gda_server_provider_handler_use_default (GdaServerProvider *provider, GType type)
 {
 	GdaDataHandler *dh = NULL;
+	g_return_val_if_fail (GDA_IS_SERVER_PROVIDER (provider), NULL);
 	if ((type == G_TYPE_INT64) ||
 	    (type == G_TYPE_UINT64) ||
 	    (type == G_TYPE_DOUBLE) ||
@@ -187,6 +190,26 @@ gda_server_provider_get_data_handler_default (GdaServerProvider *provider, G_GNU
 	return dh;
 }
 
+/**
+ * gda_server_provider_get_data_handler_default:
+ * @provider: a server provider.
+ * @cnc: (allow-none): a #GdaConnection object, or %NULL
+ * @type: a #GType
+ * @dbms_type: a DBMS type definition
+ *
+ * Provides the implementation when the default Libgda's data handlers must be used
+ * 
+ * Returns: (transfer none): a #GdaDataHandler, or %NULL
+ *
+ * Deprecated: 5.2: use gda_server_provider_handler_use_default() instead
+ */
+GdaDataHandler *
+gda_server_provider_get_data_handler_default (GdaServerProvider *provider, G_GNUC_UNUSED GdaConnection *cnc,
+					      GType type, G_GNUC_UNUSED const gchar *dbms_type)
+{
+	return gda_server_provider_handler_use_default (provider, type);
+}
+
 static gboolean
 param_to_null_foreach (GdaSqlAnyPart *part, G_GNUC_UNUSED gpointer data, G_GNUC_UNUSED GError **error)
 {
@@ -262,323 +285,24 @@ gda_select_alter_select_for_empty (GdaStatement *stmt, G_GNUC_UNUSED GError **er
 	return estmt;
 }
 
-/**
- * gda_server_provider_get_schema_nb_columns:
- * @schema: a #GdaConnectionSchema
- *
- * Returns: the number of columns the #GdaDataModel for the requested schema
- * must have
- *
- * Deprecated: 4.2: This was a leftover from the pre 4.0 area
- */
-gint
-gda_server_provider_get_schema_nb_columns (GdaConnectionSchema schema)
-{
-	switch (schema) {
-	case GDA_CONNECTION_SCHEMA_AGGREGATES:
-		return 7;
-	case GDA_CONNECTION_SCHEMA_DATABASES:
-		return 1;
-	case GDA_CONNECTION_SCHEMA_FIELDS:
-		return 10;
-        case GDA_CONNECTION_SCHEMA_INDEXES:
-		return 1;
-        case GDA_CONNECTION_SCHEMA_LANGUAGES:
-		return 1;
-        case GDA_CONNECTION_SCHEMA_NAMESPACES:
-		return 1;
-        case GDA_CONNECTION_SCHEMA_PARENT_TABLES:
-		return 2;
-        case GDA_CONNECTION_SCHEMA_PROCEDURES:
-		return 8;
-        case GDA_CONNECTION_SCHEMA_SEQUENCES:
-		return 4;
-        case GDA_CONNECTION_SCHEMA_TABLES:
-		return 4;
-        case GDA_CONNECTION_SCHEMA_TRIGGERS:
-		return 1;
-        case GDA_CONNECTION_SCHEMA_TYPES:
-		return 5;
-        case GDA_CONNECTION_SCHEMA_USERS:
-		return 1;
-        case GDA_CONNECTION_SCHEMA_VIEWS:
-		return 4;
-	case GDA_CONNECTION_SCHEMA_CONSTRAINTS:
-		return 5;
-	default:
-		g_assert_not_reached ();
-	}
-}
-
-typedef struct {
-        gchar        *col_name;
-        GType  data_type;
-} GdaSchemaColData;
-
-GdaSchemaColData aggs_spec [] = {
-	/* To translators: "Aggregate": the noun */
-	{ N_("Aggregate"), G_TYPE_STRING},
-	{ N_("Id"), G_TYPE_STRING},
-	{ N_("Owner"), G_TYPE_STRING},
-	{ N_("Comments"), G_TYPE_STRING},
-	{ N_("OutType"), G_TYPE_STRING},
-	{ N_("InType"), G_TYPE_STRING},
-	{ N_("Definition"), G_TYPE_STRING}
-};
-
-GdaSchemaColData dbs_spec [] = {
-	{ N_("Database"), G_TYPE_STRING}
-};
-
-GdaSchemaColData fields_spec [] = {
-	{ N_("Field name"), G_TYPE_STRING},
-	{ N_("Data type"), G_TYPE_STRING},
-	{ N_("Size"), G_TYPE_INT},
-	{ N_("Scale"), G_TYPE_INT},
-	{ N_("Not null?"), G_TYPE_BOOLEAN},
-	{ N_("Primary key?"), G_TYPE_BOOLEAN},
-	{ N_("Unique index?"), G_TYPE_BOOLEAN},
-	{ N_("References"), G_TYPE_STRING},
-	{ N_("Default value"), G_TYPE_STRING},
-	{ N_("Extra attributes"), G_TYPE_STRING}
-};
-
-GdaSchemaColData indexes_spec [] = {
-	{ N_("Index"), G_TYPE_STRING}
-};
-
-GdaSchemaColData lang_spec [] = {
-	{ N_("Language"), G_TYPE_STRING}
-};
-
-GdaSchemaColData ns_spec [] = {
-	{ N_("Namespace"), G_TYPE_STRING}
-};
-
-GdaSchemaColData parent_spec [] = {
-	{ N_("Table"), G_TYPE_STRING},
-	{ N_("Sequence"), G_TYPE_INT}
-};
-
-GdaSchemaColData procs_spec [] = {
-	{ N_("Procedure"), G_TYPE_STRING},
-	{ N_("Id"), G_TYPE_STRING},
-	{ N_("Owner"), G_TYPE_STRING},
-	{ N_("Comments"), G_TYPE_STRING},
-	{ N_("Return type"), G_TYPE_STRING},
-	/* To translators: "Nb args": the procedure's number of arguments */
-	{ N_("Nb args"), G_TYPE_INT},
-	{ N_("Args types"), G_TYPE_STRING},
-	{ N_("Definition"), G_TYPE_STRING}
-};
-
-GdaSchemaColData seq_spec [] = {
-	{ N_("Sequence"), G_TYPE_STRING},
-	{ N_("Owner"), G_TYPE_STRING},
-	{ N_("Comments"), G_TYPE_STRING},
-	{ N_("Definition"), G_TYPE_STRING}
-};
-
-GdaSchemaColData table_spec [] = {
-	{ N_("Table"), G_TYPE_STRING},
-	{ N_("Owner"), G_TYPE_STRING},
-	{ N_("Description"), G_TYPE_STRING},
-	{ N_("Definition"), G_TYPE_STRING}
-};
-
-GdaSchemaColData trigger_spec [] = {
-	{ N_("Trigger"), G_TYPE_STRING}
-};
-
-GdaSchemaColData types_spec [] = {
-	{ N_("Type"), G_TYPE_STRING},
-	{ N_("Owner"), G_TYPE_STRING},
-	{ N_("Comments"), G_TYPE_STRING},
-	{ N_("GDA type"), G_TYPE_ULONG},
-	{ N_("Synonyms"), G_TYPE_STRING}
-};
-
-GdaSchemaColData user_spec [] = {
-	{ N_("User"), G_TYPE_STRING}
-};
-
-GdaSchemaColData view_spec [] = {
-	{ N_("View"), G_TYPE_STRING},
-	{ N_("Owner"), G_TYPE_STRING},
-	{ N_("Description"), G_TYPE_STRING},
-	{ N_("Definition"), G_TYPE_STRING}
-};
-
-GdaSchemaColData constraint_spec [] = {
-	{ N_("Name"), G_TYPE_STRING},
-	{ N_("Type"), G_TYPE_STRING},
-	{ N_("Fields"), G_TYPE_STRING},
-	{ N_("Definition"), G_TYPE_STRING},
-	{ N_("Options"), G_TYPE_STRING}
-};
-
-static GdaSchemaColData *
-schema_get_spec (GdaConnectionSchema schema)
-{
-	GdaSchemaColData *spec = NULL;
-
-	switch (schema) {
-	case GDA_CONNECTION_SCHEMA_AGGREGATES:
-		spec = aggs_spec;
-		break;
-	case GDA_CONNECTION_SCHEMA_DATABASES:
-		spec = dbs_spec;
-		break;
-	case GDA_CONNECTION_SCHEMA_FIELDS:
-		spec = fields_spec;
- 		break;
-	case GDA_CONNECTION_SCHEMA_INDEXES:
-		spec = indexes_spec;
- 		break;
-	case GDA_CONNECTION_SCHEMA_LANGUAGES:
-		spec = lang_spec;
- 		break;
-	case GDA_CONNECTION_SCHEMA_NAMESPACES:
-		spec = ns_spec;
- 		break;
-	case GDA_CONNECTION_SCHEMA_PARENT_TABLES:
-		spec = parent_spec;
- 		break;
-	case GDA_CONNECTION_SCHEMA_PROCEDURES:
-		spec = procs_spec;
- 		break;
-	case GDA_CONNECTION_SCHEMA_SEQUENCES:
-		spec = seq_spec;
- 		break;
-	case GDA_CONNECTION_SCHEMA_TABLES:
-		spec = table_spec;
- 		break;
-	case GDA_CONNECTION_SCHEMA_TRIGGERS:
-		spec = trigger_spec;
-  		break;
-	case GDA_CONNECTION_SCHEMA_TYPES:
-		spec = types_spec;
-   		break;
-	case GDA_CONNECTION_SCHEMA_USERS:
-		spec = user_spec;
-   		break;
-	case GDA_CONNECTION_SCHEMA_VIEWS:
-		spec = view_spec;
-		break;
-	case GDA_CONNECTION_SCHEMA_CONSTRAINTS:
-		spec = constraint_spec;
-		break;
-	default:
-		g_assert_not_reached ();
-	}
-
-	return spec;
-}
-
-/**
- * gda_server_provider_init_schema_model:
- * @model: a #GdaDataModel
- * @schema: a #GdaConnectionSchema
- *
- * Sets the column attributes of @model for the requested schema
- *
- * Returns: %TRUE if there was no error
- *
- * Deprecated: 4.2: This was a leftover from the pre 4.0 area
- */
-gboolean
-gda_server_provider_init_schema_model (GdaDataModel *model, GdaConnectionSchema schema)
-{
-	GdaSchemaColData *spec = NULL;
-	gint nbcols, i;
-	GdaColumn *column;
-
-	g_return_val_if_fail (model && GDA_IS_DATA_MODEL (model), FALSE);
-	spec = schema_get_spec (schema);
-
-	nbcols = gda_server_provider_get_schema_nb_columns (schema);
-	if (gda_data_model_get_n_columns (model) != nbcols)
-		return FALSE;
-
-	for (i = 0; i < nbcols; i++) {
-                column = gda_data_model_describe_column (GDA_DATA_MODEL (model), i);
-
-                gda_column_set_description (column, spec[i].col_name);
-                gda_column_set_name (column, spec[i].col_name);
-                gda_column_set_g_type (column, spec[i].data_type);
-        }
-
-	return TRUE;
-}
-
-/**
- * gda_server_provider_test_schema_model:
- * @model: a #GdaDataModel to test
- * @schema:
- * @error:
- *
- * Test that the structure of @model is correct in regard with @schema
- *
- * Returns: %TRUE if @model has the correct structure
- *
- * Deprecated: 4.2: This was a leftover from the pre 4.0 area
- */
-gboolean
-gda_server_provider_test_schema_model (GdaDataModel *model, GdaConnectionSchema schema, GError **error)
-{
-	gint i, nbcols;
-	GdaSchemaColData *spec = NULL;
-
-	g_return_val_if_fail (model && GDA_IS_DATA_MODEL (model), FALSE);
-
-	nbcols = gda_data_model_get_n_columns (model);
-	if (nbcols < gda_server_provider_get_schema_nb_columns (schema)) {
-		g_set_error (error, 0, 0, "%s", 
-			     _("Data model for schema has a wrong number of columns"));
-		return FALSE;
-	}
-
-	spec = schema_get_spec (schema);
-	for (i = 0; i < nbcols; i++) {
-		GdaColumn *column;
-
-                column = gda_data_model_describe_column (GDA_DATA_MODEL (model), i);
-
-		if (strcmp (gda_column_get_description (column), spec[i].col_name)) {
-			g_set_error (error, 0, 0,
-				     _("Data model for schema has a wrong column title: '%s' instead of '%s'"),
-				     gda_column_get_description (column), spec[i].col_name);
-			return FALSE;
-		}
-
-		if (strcmp (gda_column_get_name (column), spec[i].col_name)) {
-			g_set_error (error, 0, 0,
-				     _("Data model for schema has a wrong column name: '%s' instead of '%s'"),
-				     gda_column_get_name (column), spec[i].col_name);
-			return FALSE;
-		}
-
-		if (gda_column_get_g_type (column) != spec[i].data_type) {
-			g_set_error (error, 0, 0,
-				     _("Data model for schema has a wrong gda type: %s instead of %s"),
-				     gda_g_type_to_string (gda_column_get_g_type (column)), 
-				     gda_g_type_to_string (spec[i].data_type));
-			return FALSE;
-		}
-        }
-	return TRUE;
-}
-
 /**
  * gda_server_provider_handler_find:
+ * @prov: a #GdaServerProvider
+ * @cnc: (allow-none): a #GdaConnection
+ * @g_type: a #GType
+ * @dbms_type: (allow-none): a database type
  *
- * Returns: (transfer none):
+ * reserved to database provider's implementations: get the #GdaDataHandler associated to @prov
+ * for connection @cnc.
  *
+ * Returns: (transfer none): the requested #GdaDataHandler, or %NULL if none found
  */
 GdaDataHandler *
 gda_server_provider_handler_find (GdaServerProvider *prov, GdaConnection *cnc, 
 				  GType g_type, const gchar *dbms_type)
 {
+	g_return_val_if_fail (GDA_IS_SERVER_PROVIDER (prov), NULL);
+
 	GdaDataHandler *dh;
 	GdaServerProviderHandlerInfo info;
 
@@ -596,6 +320,7 @@ gda_server_provider_handler_declare (GdaServerProvider *prov, GdaDataHandler *dh
 				     GType g_type, const gchar *dbms_type)
 {
 	GdaServerProviderHandlerInfo *info;
+	g_return_if_fail (GDA_IS_SERVER_PROVIDER (prov));
 	g_return_if_fail (GDA_IS_DATA_HANDLER (dh));
 	
 	info = g_new (GdaServerProviderHandlerInfo, 1);
@@ -624,6 +349,7 @@ gda_server_provider_find_file (GdaServerProvider *prov, const gchar *inst_dir, c
 	gchar *file = NULL;
 	const gchar *dirname;
 
+	g_return_val_if_fail (GDA_IS_SERVER_PROVIDER (prov), NULL);
 	dirname = g_object_get_data (G_OBJECT (prov), "GDA_PROVIDER_DIR");
 	if (dirname)
 		file = g_build_filename (dirname, filename, NULL);
@@ -682,7 +408,7 @@ gda_server_provider_load_file_contents (const gchar *inst_dir, const gchar *data
 		goto theend;
 	
 	g_free (file);
-	file = g_build_filename (inst_dir, "..", "..", "..", "share", "libgda-4.0", filename, NULL);
+	file = g_build_filename (inst_dir, "..", "..", "..", "share", "libgda-5.0", filename, NULL);
 	if (g_file_get_contents (file, &contents, NULL, NULL))
 		goto theend;
 	contents = NULL;
