@@ -5,8 +5,8 @@
  * Copyright (C) 2003 Paisa Seeluangsawat <paisa@users.sf.net>
  * Copyright (C) 2004 Caolan McNamara <caolanm@redhat.com>
  * Copyright (C) 2004 Jrg Billeter <j@bitron.ch>
- * Copyright (C) 2004 - 2010 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2004 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2005 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2007 - 2009 Armin Burgmeier <armin@openismus.com>
  * Copyright (C) 2008 - 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2008 Phil Longstaff <plongstaff@rogers.com>
@@ -675,7 +675,7 @@ gda_utility_holder_load_attributes (GdaHolder *holder, xmlNodePtr node, GSList *
 
 	/* set restricting source if specified */
 	if (str && sources) {
-		gchar *ptr1, *ptr2 = NULL, *tok;
+		gchar *ptr1, *ptr2 = NULL, *tok = NULL;
 		gchar *source;
 			
 		source = g_strdup ((gchar*)str);
@@ -1517,7 +1517,7 @@ null_param_unknown_foreach_func (GdaSqlAnyPart *part, NullData *data, GError **e
 }
 
 /**
- * gda_rewrite_sql_statement_for_null_parameters: (skip):
+ * gda_rewrite_sql_statement_for_null_parameters: (skip)
  * @sqlst: (transfer full): a #GdaSqlStatement
  * @params: a #GdaSet to be used as parameters when executing @stmt
  * @out_modified: (allow-none): a place to store the boolean which tells if @stmt has been modified or not, or %NULL
