@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -897,7 +897,7 @@ gda_ldap_entry_new (const gchar *dn)
 		entry->dn = g_strdup (dn);
 	entry->attributes_hash = g_hash_table_new (g_str_hash, g_str_equal);
 	entry->nb_attributes = 0;
-	entry->attributes = g_new0 (GdaLdapAttribute, 1);
+	entry->attributes = g_new0 (GdaLdapAttribute*, 1);
 	return entry;
 }
 
