@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2007 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2007 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
@@ -116,7 +116,7 @@ gda_vconnection_hub_get_type (void)
 				(GInstanceInitFunc) gda_vconnection_hub_init,
 				0
 			};
-			
+
 		g_static_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GDA_TYPE_VCONNECTION_DATA_MODEL, "GdaVconnectionHub", &info, 0);
@@ -143,7 +143,7 @@ gda_vconnection_hub_get_type (void)
  * Returns: TRUE if no error occurred
  */
 gboolean
-gda_vconnection_hub_add (GdaVconnectionHub *hub, 
+gda_vconnection_hub_add (GdaVconnectionHub *hub,
 			 GdaConnection *cnc, const gchar *ns, GError **error)
 {
 	HubConnection *hc;
@@ -176,7 +176,7 @@ gda_vconnection_hub_add (GdaVconnectionHub *hub,
 	hc->cnc = cnc;
 	g_object_ref (cnc);
 	hc->ns = ns ? g_strdup (ns) : NULL;
-	
+
 	if (!attach_hub_connection (hub, hc, error)) {
 		hub_connection_free (hc);
 		return FALSE;
@@ -222,7 +222,7 @@ get_hub_cnc_by_ns (GdaVconnectionHub *hub, const gchar *ns)
 {
 	GSList *list;
 	for (list = hub->priv->hub_connections; list; list = list->next) {
-		if ((!ns && !((HubConnection*) list->data)->ns)|| 
+		if ((!ns && !((HubConnection*) list->data)->ns)||
 		    (ns && ((HubConnection*) list->data)->ns && !strcmp (((HubConnection*) list->data)->ns, ns)))
 			return (HubConnection*) list->data;
 	}
@@ -272,7 +272,7 @@ gda_vconnection_hub_get_connection (GdaVconnectionHub *hub, const gchar *ns)
  * Call @func for each #GdaConnection represented in @hub.
  */
 void
-gda_vconnection_hub_foreach (GdaVconnectionHub *hub, 
+gda_vconnection_hub_foreach (GdaVconnectionHub *hub,
 			     GdaVConnectionHubFunc func, gpointer data)
 {
 	GSList *list, *next;
@@ -332,7 +332,7 @@ compute_column_specs (GdaVconnectionDataModelSpec *spec)
 	if (lspec->col_names)
 		return;
 
-	model = gda_connection_get_meta_store_data (lspec->hc->cnc, 
+	model = gda_connection_get_meta_store_data (lspec->hc->cnc,
 						    GDA_CONNECTION_META_FIELDS, NULL, 1, "name", lspec->table_name);
 	if (!model)
 		return;
@@ -355,6 +355,8 @@ compute_column_specs (GdaVconnectionDataModelSpec *spec)
 
 		lspec->col_names[i] = g_value_dup_string (v0);
 		lspec->col_gtypes[i] = gda_g_type_from_string (g_value_get_string (v2));
+		if (lspec->col_gtypes[i] == G_TYPE_INVALID)
+			lspec->col_gtypes[i] = GDA_TYPE_NULL;
 		lspec->col_dtypes[i] = g_value_dup_string (v1);
 	}
 	g_object_unref (model);
@@ -511,7 +513,7 @@ dict_table_create_filter (GdaVconnectionDataModelSpec *spec, GdaVconnectionDataM
 		gda_sql_builder_set_where (b, whid);
 	}
 	g_free (op_ids);
-	
+
 	/* ORDER BY part */
 	info->orderByConsumed = FALSE;
 	for (i = 0; i < info->nOrderBy; i++) {
@@ -553,7 +555,7 @@ dict_table_create_filter (GdaVconnectionDataModelSpec *spec, GdaVconnectionDataM
 			lspec->filters_hash = g_hash_table_new_full (g_str_hash, g_str_equal,
 								     g_free,
 								     (GDestroyNotify) computed_filter_free);
-		
+
 		g_hash_table_insert (lspec->filters_hash, hash, filter);
 		info->idxPointer = filter->stmt;
 		/*g_print ("There are now %d statements in store...\n", g_hash_table_size (lspec->filters_hash));*/
@@ -581,8 +583,7 @@ create_value_from_sqlite3_gvalue (GType type, GValue *svalue, GError **error)
 	gboolean allok = TRUE;
 	value = g_new0 (GValue, 1);
 
-	if (type != GDA_TYPE_NULL)
-		g_value_init (value, type);
+	g_value_init (value, type);
 
 	if (type == GDA_TYPE_NULL)
 		;
@@ -651,7 +652,7 @@ create_value_from_sqlite3_gvalue (GType type, GValue *svalue, GError **error)
 	else if (type == GDA_TYPE_BLOB) {
 		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
 			     GDA_SERVER_PROVIDER_DATA_ERROR,
-			     _("Blob constraints are not handled in virtual table condition"));
+			     "%s", _("Blob constraints are not handled in virtual table condition"));
 		allok = FALSE;
 	}
 	else if (type == G_TYPE_BOOLEAN) {
@@ -721,7 +722,7 @@ create_value_from_sqlite3_gvalue (GType type, GValue *svalue, GError **error)
 }
 
 static GdaDataModel *
-dict_table_create_model_func (GdaVconnectionDataModelSpec *spec, int idxNum, const char *idxStr,
+dict_table_create_model_func (GdaVconnectionDataModelSpec *spec, G_GNUC_UNUSED int idxNum, const char *idxStr,
 			      int argc, GValue **argv)
 {
 	GdaDataModel *model;
@@ -736,7 +737,7 @@ dict_table_create_model_func (GdaVconnectionDataModelSpec *spec, int idxNum, con
 		if (! gda_statement_get_parameters (stmt, &params, NULL))
 			return NULL;
 		if (argc > 0) {
-			g_assert (params && (argc == g_slist_length (params->holders)));
+			g_assert (params && ((guint)argc == g_slist_length (params->holders)));
 			for (i = 0, list = params->holders; i < argc; i++, list = list->next) {
 				GdaHolder *holder = GDA_HOLDER (list->data);
 				GValue *value;
@@ -783,7 +784,7 @@ dict_table_create_model_func (GdaVconnectionDataModelSpec *spec, int idxNum, con
 	g_object_unref (stmt);
 	if (params)
 		g_object_unref (params);
-	if (model) 
+	if (model)
 		gda_data_select_compute_modification_statements (GDA_DATA_SELECT (model), NULL);
 	else {
 		gda_log_message ("Virtual table: data model error: %s",
@@ -804,7 +805,7 @@ attach_hub_connection (GdaVconnectionHub *hub, HubConnection *hc, GError **error
 	GdaMetaStore *store;
 	GdaMetaContext context;
 	GdaConnectionOptions options;
-	
+
 	store = gda_connection_get_meta_store (hc->cnc);
 	g_assert (store);
 	g_object_get ((GObject*) hc->cnc, "options", &options, NULL);
@@ -880,7 +881,8 @@ meta_changed_cb (G_GNUC_UNUSED GdaMetaStore *store, GSList *changes, HubConnecti
 	for (list = changes; list; list = list->next) {
 		GdaMetaStoreChange *ch = (GdaMetaStoreChange*) list->data;
 		GValue *tsn, *tn;
-		/* we are only intsrested in changes occurring in the "_tables" table */
+
+		/* we are only interested in changes occurring in the "_tables" table */
 		if (!strcmp (ch->table_name, "_tables")) {
 			switch (ch->c_type) {
 			case GDA_META_STORE_ADD: {
@@ -989,7 +991,7 @@ detach_hub_connection (GdaVconnectionHub *hub, HubConnection *hc)
 		g_assert (stmt);
 		gda_connection_statement_execute_non_select (GDA_CONNECTION (hub), stmt, NULL, NULL, NULL);
 		g_object_unref (stmt);
-	}	
+	}
 
 	hub->priv->hub_connections = g_slist_remove (hub->priv->hub_connections, hc);
 	hub_connection_free (hc);
