@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2007 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
@@ -230,7 +230,7 @@ virtual_filtered_data_new (VirtualTable *vtable, GdaDataModel *model,
 	gint n;
 	n = gda_data_model_get_n_columns (model);
 	n = (n >= 0) ? n : 1;
-	data->values = g_value_array_new (n);
+	data->values_array = g_array_new (FALSE, FALSE, sizeof (GValue));
 	data->ncols = gda_data_model_get_n_columns (model);
 	data->nrows = -1;
 	data->rowid_offset = vtable->rows_offset;
@@ -259,8 +259,15 @@ virtual_filtered_data_free (VirtualFilteredData *data)
 	if (data->iter)
 		g_object_unref (data->iter);
 
-	if (data->values)
-		g_value_array_free (data->values);
+	if (data->values_array) {
+		guint i;
+		for (i = 0; i < data->values_array->len; i++) {
+			GValue *value;
+			value = & g_array_index (data->values_array, GValue, i);
+			g_value_reset (value);
+		}
+		g_array_free (data->values_array, TRUE);
+	}
 	g_free (data);
 
 #ifdef DEBUG_VCONTEXT
@@ -334,9 +341,11 @@ static sqlite3_module Module = {
 	virtualRollback,              /* xRollback - rollback transaction */
 	NULL,                         /* xFindFunction - function overloading */
 	virtualRename,                /* Rename - Notification that the table will be given a new name */
+#if SQLITE_VERSION_NUMBER >= 3007007
 	NULL,                         /* xSavepoint */  
 	NULL,                         /* xRelease */
 	NULL                          /* xRollbackTo */
+#endif
 };
 
 static GdaConnection *
@@ -525,7 +534,7 @@ virtualCreate (sqlite3 *db, void *pAux, int argc, const char *const *argv, sqlit
 	if (*spec_name == '\'')
 		memmove (spec_name, spec_name+1, i);
 
-	td = gda_vconnection_get_table_data_by_unique_name (cnc, spec_name);
+	td = _gda_vconnection_get_table_data_by_unique_name (cnc, spec_name);
 	g_free (spec_name);
 	if (!td) {
 		/* wrong usage! */
@@ -585,8 +594,28 @@ virtualCreate (sqlite3 *db, void *pAux, int argc, const char *const *argv, sqlit
 		name = gda_column_get_name (column);
 		if (!name || !(*name))
 			newcolname = g_strdup_printf ("_%d", i + 1);
-		else
+		else {
+			GString *string;
+			gchar *ptr;
+			string = g_string_new ("");
 			newcolname = gda_sql_identifier_quote (name, GDA_CONNECTION (cnc), NULL, FALSE, FALSE);
+			for (ptr = newcolname; *ptr; ptr++) {
+				if ((*ptr == '_') ||
+				    ((*ptr >= 'a') && (*ptr <= 'z')) ||
+				    ((*ptr >= 'A') && (*ptr <= 'Z')))
+					g_string_append_c (string, *ptr);
+				else if ((*ptr >= '0') && (*ptr <= '9')) {
+					if (ptr == name)
+						g_string_append_c (string, '_');
+					else
+						g_string_append_c (string, *ptr);
+				}
+				else
+					g_string_append_c (string, '_');
+			}
+			g_free (newcolname);
+			newcolname = g_string_free (string, FALSE);
+		}
 
 		tmp = g_ascii_strdown (newcolname, -1);
 		if (g_hash_table_lookup (hash, tmp)) {
@@ -694,7 +723,7 @@ virtualConnect (sqlite3 *db, void *pAux, int argc, const char *const *argv, sqli
 static int
 virtualDisconnect (sqlite3_vtab *pVtab)
 {
-	VirtualTable *vtable = (VirtualTable *) pVtab;
+	/*VirtualTable *vtable = (VirtualTable *) pVtab;*/
 
 	TRACE (pVtab, NULL);
 	g_free (pVtab);
@@ -727,7 +756,7 @@ static int
 virtualClose (sqlite3_vtab_cursor *cur)
 {
 	VirtualCursor *cursor = (VirtualCursor*) cur;
-	VirtualTable *vtable = (VirtualTable*) cur->pVtab;
+	/*VirtualTable *vtable = (VirtualTable*) cur->pVtab;*/
 
 	TRACE (cur->pVtab, cur);
 
@@ -831,13 +860,23 @@ virtualNext (sqlite3_vtab_cursor *cur)
 					GValue value = {0};
 					g_value_init (&value, G_TYPE_ERROR);
 					g_value_take_boxed (&value, lerror);
-					g_value_array_append (data->values, &value);
-					g_value_unset (&value);
+					g_array_append_val (data->values_array, value);
 				}
 				else {
 					const GValue *cvalue;
 					cvalue = gda_holder_get_value (h);
-					g_value_array_append (data->values, cvalue);
+					if (cvalue && (G_VALUE_TYPE (cvalue) != 0)) {
+						GValue copy = {0};
+						g_value_init (&copy, G_VALUE_TYPE (cvalue));
+						g_value_copy (cvalue, &copy);
+						g_array_append_val (data->values_array, copy);
+					}
+					else {
+						GValue value = {0};
+						g_value_init (&value, G_TYPE_ERROR);
+						g_value_take_boxed (&value, lerror);
+						g_array_append_val (data->values_array, value);
+					}
 				}
 			}
 			g_assert (count == data->ncols);
@@ -900,7 +939,7 @@ get_data_value (VirtualTable *vtable, VirtualCursor *cursor, gint row, gint64 ro
 	}
 
 	if (data)
-		value = g_value_array_get_nth (data->values, row * data->ncols + col);
+		value = & g_array_index (data->values_array, GValue, row * data->ncols + col);
 
 	if (!value)
 		g_set_error (error, 0, 0,
