@@ -179,7 +179,8 @@ static gchar * firebird_render_expr (GdaSqlExpr *expr, GdaSqlRenderingContext *c
  * TO_ADD: any prepared statement to be used internally by the provider should be
  *         declared here, as constants and as SQL statements
  */
-GdaStatement **internal_stmt;
+static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
+static GdaStatement **internal_stmt = NULL;
 
 typedef enum {
 	INTERNAL_STMT1
@@ -296,19 +297,24 @@ gda_firebird_provider_class_init (GdaFirebirdProviderClass *klass)
 static void
 gda_firebird_provider_init (GdaFirebirdProvider *firebird_prv, GdaFirebirdProviderClass *klass)
 {
-	InternalStatementItem i;
-	GdaSqlParser *parser;
+	g_static_mutex_lock (&init_mutex);
+	if (!internal_stmt) {
+		InternalStatementItem i;
+		GdaSqlParser *parser;
 
-	parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) firebird_prv);
-	internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
-	for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
-		internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
-		if (!internal_stmt[i]) 
-			g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+		parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) firebird_prv);
+		internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
+		for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
+			internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
+			if (!internal_stmt[i])
+				g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+		}
 	}
 
 	/* meta data init */
 	_gda_firebird_provider_meta_init ((GdaServerProvider*) firebird_prv);
+
+	g_static_mutex_unlock (&init_mutex);
 }
 
 GType
@@ -988,7 +994,7 @@ gda_firebird_provider_get_data_handler (GdaServerProvider *provider, GdaConnecti
 		dh = NULL;
 	}
 	else
-		dh = gda_server_provider_get_data_handler_default (provider, cnc, type, dbms_type);
+		dh = gda_server_provider_handler_use_default (provider, type);
 
 	return dh;
 }
@@ -1695,19 +1701,23 @@ gda_firebird_provider_statement_execute (GdaServerProvider *provider,
 			*/
 		}
 		else {
-			gchar *str;
 			GdaDataHandler *data_handler =
 				gda_server_provider_get_data_handler_g_type (provider, cnc, 
 									     G_VALUE_TYPE (value));
 			if (data_handler == NULL) {
 				/* there is an error here */
+				gchar *str;
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
+				str = g_strdup_printf (_("Unhandled data type '%s'"),
+						       gda_g_type_to_string (G_VALUE_TYPE (value)));
 				gda_connection_event_set_description (event, str);
 				g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
 					     GDA_SERVER_PROVIDER_DATA_ERROR, "%s", str);
+				g_free (str);
 				break;
 			}
 			else {
+				gchar *str;
 				short *flag0 = g_new0 (short, 1);
 				mem_to_free = g_slist_prepend (mem_to_free, flag0);
 				
