@@ -145,7 +145,8 @@ static void gda_jdbc_free_cnc_data (JdbcConnectionData *cdata);
  * TO_ADD: any prepared statement to be used internally by the provider should be
  *         declared here, as constants and as SQL statements
  */
-static GdaStatement **internal_stmt;
+static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
+static GdaStatement **internal_stmt = NULL;
 
 typedef enum {
 	INTERNAL_STMT1
@@ -266,21 +267,27 @@ extern JavaVM *_jdbc_provider_java_vm;
 static void
 gda_jdbc_provider_init (GdaJdbcProvider *jdbc_prv, G_GNUC_UNUSED GdaJdbcProviderClass *klass)
 {
-	InternalStatementItem i;
-	GdaSqlParser *parser;
+	g_static_mutex_lock (&init_mutex);
 
-	parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) jdbc_prv);
-	internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
-	for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
-		internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
-		if (!internal_stmt[i]) 
-			g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+	if (!internal_stmt) {
+		InternalStatementItem i;
+		GdaSqlParser *parser;
+
+		parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) jdbc_prv);
+		internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
+		for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
+			internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
+			if (!internal_stmt[i])
+				g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+		}
 	}
 
 	/* meta data init */
 	_gda_jdbc_provider_meta_init ((GdaServerProvider*) jdbc_prv);
 
 	/* TO_ADD: any other provider's init should be added here */
+
+	g_static_mutex_unlock (&init_mutex);
 }
 
 GType
@@ -475,7 +482,7 @@ gda_jdbc_provider_get_server_version (GdaServerProvider *provider, GdaConnection
 		return FALSE;
 
 	if (! cdata->server_version && cdata->jcnc_obj) {
-		JNIEnv *jenv;
+		JNIEnv *jenv = NULL;
 		gboolean jni_detach;
 		GError *error = NULL;
 
@@ -948,7 +955,7 @@ gda_jdbc_provider_get_data_handler (GdaServerProvider *provider, GdaConnection *
                 }
 	}
 	else
-		dh = gda_server_provider_get_data_handler_default (provider, cnc, type, dbms_type);
+		dh = gda_server_provider_handler_use_default (provider, type);
 
 	return dh;
 }
@@ -1077,13 +1084,14 @@ gda_jdbc_provider_statement_prepare (GdaServerProvider *provider, GdaConnection
                 return FALSE;
         sql = gda_jdbc_provider_statement_to_sql (provider, cnc, stmt, params, GDA_STATEMENT_SQL_PARAMS_AS_UQMARK,
 						  &used_params, error);
+
+	JNIEnv *jenv = NULL;
         if (!sql)
 		goto out;
 
 	/* prepare @stmt using the C API, creates @ps */
 	GValue *pstmt_obj;
-	JNIEnv *jenv = NULL;
-	gboolean jni_detach;
+	gboolean jni_detach = FALSE;
 	jstring jsql;
 	
 	jenv = _gda_jdbc_get_jenv (&jni_detach, error);
@@ -1783,7 +1791,7 @@ gda_jdbc_free_cnc_data (JdbcConnectionData *cdata)
 
 	if (cdata->jcnc_obj) {
 		/* force the connection to be closed */
-		JNIEnv *jenv;
+		JNIEnv *jenv = NULL;
 		gboolean jni_detach;
 		GError *error = NULL;
 
