@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 - 2009 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -96,11 +96,10 @@ static gchar *internal_sql[] = {
  * global static values, and
  * predefined statements' GdaStatement, all initialized in _gda_oracle_provider_meta_init()
  */
-static GdaStatement **internal_stmt;
-static GdaSet        *i_set;
+static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
+static GdaStatement **internal_stmt = NULL;
+static GdaSet        *i_set = NULL;
 static GdaSqlParser  *internal_parser = NULL;
-/* TO_ADD: other static values */
-
 
 /*
  * Meta initialization
@@ -108,24 +107,24 @@ static GdaSqlParser  *internal_parser = NULL;
 void
 _gda_oracle_provider_meta_init (GdaServerProvider *provider)
 {
-	static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
-	InternalStatementItem i;
-
 	g_static_mutex_lock (&init_mutex);
 
-        internal_parser = gda_server_provider_internal_get_parser (provider);
-        internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
-        for (i = I_STMT_CATALOG; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
-                internal_stmt[i] = gda_sql_parser_parse_string (internal_parser, internal_sql[i], NULL, NULL);
-                if (!internal_stmt[i])
-                        g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
-        }
+	if (!internal_stmt) {
+		InternalStatementItem i;
+		internal_parser = gda_server_provider_internal_get_parser (provider);
+		internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
+		for (i = I_STMT_CATALOG; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
+			internal_stmt[i] = gda_sql_parser_parse_string (internal_parser, internal_sql[i], NULL, NULL);
+			if (!internal_stmt[i])
+				g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+		}
 
-	/* initialize static values here */
-	i_set = gda_set_new_inline (4, "cat", G_TYPE_STRING, "", 
-				    "name", G_TYPE_STRING, "",
-				    "schema", G_TYPE_STRING, "",
-				    "name2", G_TYPE_STRING, "");
+		/* initialize static values here */
+		i_set = gda_set_new_inline (4, "cat", G_TYPE_STRING, "",
+					    "name", G_TYPE_STRING, "",
+					    "schema", G_TYPE_STRING, "",
+					    "name2", G_TYPE_STRING, "");
+	}
 
 	g_static_mutex_unlock (&init_mutex);
 }
@@ -169,7 +168,7 @@ _gda_oracle_meta_udt (GdaServerProvider *prov, GdaConnection *cnc,
 		    GdaMetaStore *store, GdaMetaContext *context, GError **error,
 		    const GValue *udt_catalog, const GValue *udt_schema)
 {
-	GdaDataModel *model;
+	GdaDataModel *model = NULL;
 	gboolean retval = TRUE;
 
 	/* set internal holder's values from the arguments */
@@ -382,7 +381,7 @@ _gda_oracle_meta__tables_views (GdaServerProvider *prov, GdaConnection *cnc,
         gboolean retval = TRUE;
 
         OracleConnectionData *cdata;
-        cdata = (OracleConnectionData*) gda_connection_internal_get_provider_data (cnc);
+        cdata = (OracleConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
         if (!cdata)
                 return FALSE;
 
@@ -427,7 +426,7 @@ _gda_oracle_meta_tables_views (GdaServerProvider *prov, GdaConnection *cnc,
         gboolean retval = TRUE;
 
         OracleConnectionData *cdata;
-        cdata = (OracleConnectionData*) gda_connection_internal_get_provider_data (cnc);
+        cdata = (OracleConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
         if (!cdata)
                 return FALSE;
 
@@ -498,7 +497,7 @@ oracle_identifier_to_value (const gchar *sqlid)
 		for (ptr = sqlid; *ptr; ptr++) {
 			if ((*ptr == ' ') || (*ptr != g_ascii_toupper (*ptr))) {
 				/* add quotes */
-				g_value_take_string (v, gda_sql_identifier_add_quotes (sqlid));
+				g_value_take_string (v, gda_sql_identifier_force_quotes (sqlid));
 				return v;
 			}
 		}
@@ -506,7 +505,7 @@ oracle_identifier_to_value (const gchar *sqlid)
 		g_value_set_string (v, sqlid);
 	}
 	else
-		g_value_take_string (v, gda_sql_identifier_add_quotes (sqlid));
+		g_value_take_string (v, gda_sql_identifier_force_quotes (sqlid));
 	return v;
 }
 
@@ -519,7 +518,7 @@ _gda_oracle_meta__columns (GdaServerProvider *prov, GdaConnection *cnc,
 	gint i, nrows;
 	OracleConnectionData *cdata;
 
-	cdata = (OracleConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (OracleConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata)
 		return FALSE;
 
@@ -930,10 +929,12 @@ _gda_oracle_meta__columns (GdaServerProvider *prov, GdaConnection *cnc,
 
 	/* modify meta store with @model */
 	if (retval) {
+		/*
 		FILE *out;
 		out = fopen ("_columns", "w");
 		gda_data_model_dump (model, out);
 		fclose (out);
+		*/
 
 		gda_meta_store_set_identifiers_style (store, GDA_SQL_IDENTIFIERS_UPPER_CASE);
 		retval = gda_meta_store_modify_with_context (store, context, model, error);
