@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <stdio.h>
@@ -144,7 +144,8 @@ static void gda_capi_free_cnc_data (CapiConnectionData *cdata);
  * TO_ADD: any prepared statement to be used internally by the provider should be
  *         declared here, as constants and as SQL statements
  */
-static GdaStatement **internal_stmt;
+static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
+static GdaStatement **internal_stmt = NULL;
 
 typedef enum {
 	INTERNAL_STMT1
@@ -262,21 +263,27 @@ gda_capi_provider_class_init (GdaCapiProviderClass *klass)
 static void
 gda_capi_provider_init (GdaCapiProvider *capi_prv, G_GNUC_UNUSED GdaCapiProviderClass *klass)
 {
-	InternalStatementItem i;
-	GdaSqlParser *parser;
+	g_static_mutex_lock (&init_mutex);
 
-	parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) capi_prv);
-	internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
-	for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
-		internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
-		if (!internal_stmt[i]) 
-			g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+	if (!internal_stmt) {
+		InternalStatementItem i;
+		GdaSqlParser *parser;
+
+		parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) capi_prv);
+		internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
+		for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
+			internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
+			if (!internal_stmt[i])
+				g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+		}
 	}
 
 	/* meta data init */
 	_gda_capi_provider_meta_init ((GdaServerProvider*) capi_prv);
 
 	/* TO_ADD: any other provider's init should be added here */
+
+	g_static_mutex_unlock (&init_mutex);
 }
 
 GType
@@ -643,7 +650,7 @@ gda_capi_provider_begin_transaction (GdaServerProvider *provider, GdaConnection
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 	g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
 
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return FALSE;
 
@@ -664,7 +671,7 @@ gda_capi_provider_commit_transaction (GdaServerProvider *provider, GdaConnection
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 	g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
 
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return FALSE;
 
@@ -685,7 +692,7 @@ gda_capi_provider_rollback_transaction (GdaServerProvider *provider, GdaConnecti
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 	g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
 
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return FALSE;
 
@@ -706,7 +713,7 @@ gda_capi_provider_add_savepoint (GdaServerProvider *provider, GdaConnection *cnc
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 	g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
 
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return FALSE;
 
@@ -727,7 +734,7 @@ gda_capi_provider_rollback_savepoint (GdaServerProvider *provider, GdaConnection
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 	g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
 
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return FALSE;
 
@@ -748,7 +755,7 @@ gda_capi_provider_delete_savepoint (GdaServerProvider *provider, GdaConnection *
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 	g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
 
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return FALSE;
 
@@ -817,7 +824,7 @@ gda_capi_provider_get_data_handler (GdaServerProvider *provider, GdaConnection *
 		dh = NULL;
 	}
 	else
-		dh = gda_server_provider_get_data_handler_default (provider, cnc, type, dbms_type);
+		dh = gda_server_provider_handler_use_default (provider, type);
 
 	return dh;
 }
@@ -831,8 +838,8 @@ static const gchar*
 gda_capi_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnection *cnc, GType type)
 {
 	if (cnc) {
-		g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
-		g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
+		g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
+		g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, NULL);
 	}
 
 	TO_IMPLEMENT;
@@ -858,11 +865,9 @@ gda_capi_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnect
 	if ((type == G_TYPE_DATE) || 
 	    (type == GDA_TYPE_GEOMETRIC_POINT) ||
 	    (type == G_TYPE_OBJECT) ||
-	    (type == GDA_TYPE_LIST) ||
 	    (type == G_TYPE_STRING) ||
 	    (type == GDA_TYPE_TIME) ||
 	    (type == GDA_TYPE_TIMESTAMP) ||
-	    (type == G_TYPE_INVALID) ||
 	    (type == G_TYPE_GTYPE))
 		return "string";
 
@@ -878,6 +883,10 @@ gda_capi_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnect
 	if (type == G_TYPE_DATE)
 		return "date";
 
+	if ((type == GDA_TYPE_NULL) ||
+	    (type == G_TYPE_GTYPE))
+		return NULL;
+
 	return "text";
 }
 
@@ -1042,7 +1051,7 @@ gda_capi_provider_statement_execute (GdaServerProvider *provider, GdaConnection
                 *last_inserted_row = NULL;
 
 	/* Get private data */
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return FALSE;
 
@@ -1333,7 +1342,7 @@ gda_capi_provider_xa_start (GdaServerProvider *provider, GdaConnection *cnc,
 	g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
 	g_return_val_if_fail (xid, FALSE);
 
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return FALSE;
 
@@ -1355,7 +1364,7 @@ gda_capi_provider_xa_end (GdaServerProvider *provider, GdaConnection *cnc,
 	g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
 	g_return_val_if_fail (xid, FALSE);
 
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return FALSE;
 
@@ -1376,7 +1385,7 @@ gda_capi_provider_xa_prepare (GdaServerProvider *provider, GdaConnection *cnc,
 	g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
 	g_return_val_if_fail (xid, FALSE);
 
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return FALSE;
 
@@ -1398,7 +1407,7 @@ gda_capi_provider_xa_commit (GdaServerProvider *provider, GdaConnection *cnc,
 	g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
 	g_return_val_if_fail (xid, FALSE);
 
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return FALSE;
 
@@ -1419,7 +1428,7 @@ gda_capi_provider_xa_rollback (GdaServerProvider *provider, GdaConnection *cnc,
 	g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
 	g_return_val_if_fail (xid, FALSE);
 
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return FALSE;
 
@@ -1441,7 +1450,7 @@ gda_capi_provider_xa_recover (GdaServerProvider *provider, GdaConnection *cnc,
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
 	g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, NULL);
 
-	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (CapiConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	if (!cdata) 
 		return NULL;
 
