@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1034,7 +1034,7 @@ test13 (GError **error)
 	g_object_set (h2, "g-type", G_TYPE_STRING, NULL);
 	if (gda_holder_get_g_type (h1) != G_TYPE_STRING) {
 		g_set_error (error, 0, 0,
-			     "Bind-to holder type set did not propagate to holder's type, case 1");
+			     "%s", "Bind-to holder type set did not propagate to holder's type, case 1");
 		g_object_unref (h1);
 		g_object_unref (h2);
 		return FALSE;
@@ -1052,7 +1052,7 @@ test13 (GError **error)
 	}
 	if (gda_holder_get_g_type (h1) != G_TYPE_INT) {
 		g_set_error (error, 0, 0,
-			     "Bind-to holder type set did not propagate to holder's type, case 2");
+			     "%s", "Bind-to holder type set did not propagate to holder's type, case 2");
 		g_object_unref (h1);
 		g_object_unref (h2);
 		return FALSE;
@@ -1071,14 +1071,14 @@ test13 (GError **error)
 	g_object_set (h2, "g-type", G_TYPE_STRING, NULL);
 	if (gda_holder_get_g_type (h1) != G_TYPE_STRING) {
 		g_set_error (error, 0, 0,
-			     "Holder type changed when it should not have, case 1");
+			     "%s", "Holder type changed when it should not have, case 1");
 		g_object_unref (h1);
 		g_object_unref (h2);
 		return FALSE;
 	}
 	if (gda_holder_get_bind (h1) != h2) {
 		g_set_error (error, 0, 0,
-			     "Bind broken when it should not have been");
+			     "%s", "Bind broken when it should not have been");
 		g_object_unref (h1);
 		g_object_unref (h2);
 		return FALSE;
@@ -1097,14 +1097,14 @@ test13 (GError **error)
 	g_object_set (h2, "g-type", G_TYPE_INT, NULL);
 	if (gda_holder_get_g_type (h1) != G_TYPE_STRING) {
 		g_set_error (error, 0, 0,
-			     "Holder type changed when it should not have, case 2");
+			     "%s", "Holder type changed when it should not have, case 2");
 		g_object_unref (h1);
 		g_object_unref (h2);
 		return FALSE;
 	}
 	if (gda_holder_get_bind (h1) == h2) {
 		g_set_error (error, 0, 0,
-			     "Bind not broken when it should have been");
+			     "%s", "Bind not broken when it should have been");
 		g_object_unref (h1);
 		g_object_unref (h2);
 		return FALSE;
