@@ -318,7 +318,7 @@ sub_thread_open_cnc (AuthData *ad, GError **error)
 	return cnc;
 #else /* DUMMY defined */
 	sleep (5);
-	g_set_error (error, TOOLS_ERROR, TOOLS_INTERNAL_COMMAND_ERROR, "%s", "Dummy error!");
+	g_set_error (error, GDA_TOOLS_ERROR, TOOLS_INTERNAL_COMMAND_ERROR, "%s", "Dummy error!");
 	return NULL;
 #endif
 }
