@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -42,12 +42,16 @@ struct _BrowserConnectionPrivate {
         GdaSqlParser  *parser;
 
 	GdaDsnInfo     dsn_info;
+#if GLIB_CHECK_VERSION(2,31,7)
+	GMutex        mstruct_mutex;
+#else
 	GMutex        *p_mstruct_mutex;
+#endif
 	GSList        *p_mstruct_list; /* private GdaMetaStruct list: while they are being created */
 	GdaMetaStruct *c_mstruct; /* last GdaMetaStruct up to date, ready to be passed as @mstruct */
 	GdaMetaStruct *mstruct; /* public GdaMetaStruct: once it has been created and is no more modified */
 
-	BrowserFavorites *bfav;
+	ToolsFavorites *bfav;
 
 	gboolean  busy;
 	gchar    *busy_reason;
