@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +23,15 @@
 #include "browser-window.h"
 #include "support.h"
 
+#if GLIB_CHECK_VERSION(2,31,7)
+static GRecMutex init_rmutex;
+#define MUTEX_LOCK() g_rec_mutex_lock(&init_rmutex)
+#define MUTEX_UNLOCK() g_rec_mutex_unlock(&init_rmutex)
+#else
 static GStaticRecMutex init_mutex = G_STATIC_REC_MUTEX_INIT;
+#define MUTEX_LOCK() g_static_rec_mutex_lock(&init_mutex)
+#define MUTEX_UNLOCK() g_static_rec_mutex_unlock(&init_mutex)
+#endif
 static void browser_perspective_class_init (gpointer g_class);
 
 GType
@@ -44,12 +53,12 @@ browser_perspective_get_type (void)
 			0
 		};
 		
-		g_static_rec_mutex_lock (&init_mutex);
+		MUTEX_LOCK();
 		if (type == 0) {
 			type = g_type_register_static (G_TYPE_INTERFACE, "BrowserPerspective", &info, 0);
 			g_type_interface_add_prerequisite (type, GTK_TYPE_WIDGET);
 		}
-		g_static_rec_mutex_unlock (&init_mutex);
+		MUTEX_UNLOCK();
 	}
 	return type;
 }
@@ -59,11 +68,11 @@ browser_perspective_class_init (G_GNUC_UNUSED gpointer g_class)
 {
 	static gboolean initialized = FALSE;
 
-	g_static_rec_mutex_lock (&init_mutex);
+	MUTEX_LOCK();
 	if (! initialized) {
 		initialized = TRUE;
 	}
-	g_static_rec_mutex_unlock (&init_mutex);
+	MUTEX_UNLOCK();
 }
 
 /**
@@ -222,7 +231,7 @@ browser_perspective_declare_notebook (BrowserPerspective *perspective, GtkNotebo
 }
 
 static void
-nb_switch_page_cb (GtkNotebook *nb, GtkWidget *page, gint page_num, BrowserPerspective *perspective)
+nb_switch_page_cb (GtkNotebook *nb, G_GNUC_UNUSED GtkWidget *page, gint page_num, BrowserPerspective *perspective)
 {
 	GtkWidget *page_contents;
 	GtkActionGroup *actions = NULL;
@@ -243,7 +252,7 @@ nb_switch_page_cb (GtkNotebook *nb, GtkWidget *page, gint page_num, BrowserPersp
 }
 
 static void
-nb_page_added_or_removed_cb (GtkNotebook *nb, GtkWidget *child, guint page_num,
+nb_page_added_or_removed_cb (GtkNotebook *nb, G_GNUC_UNUSED GtkWidget *child, G_GNUC_UNUSED guint page_num,
 			     BrowserPerspective *perspective)
 {
 	adapt_notebook_for_fullscreen (perspective);
@@ -259,7 +268,7 @@ nb_page_added_or_removed_cb (GtkNotebook *nb, GtkWidget *child, guint page_num,
 }
 
 static void
-fullscreen_changed_cb (G_GNUC_UNUSED BrowserWindow *bwin, gboolean fullscreen,
+fullscreen_changed_cb (G_GNUC_UNUSED BrowserWindow *bwin, G_GNUC_UNUSED gboolean fullscreen,
 		       BrowserPerspective *perspective)
 {
 	adapt_notebook_for_fullscreen (perspective);
