@@ -1,4 +1,5 @@
 /*
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -21,7 +22,7 @@
 #include "hierarchy-view.h"
 #include "../dnd.h"
 #include "../support.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "../browser-stock-icons.h"
 #include <virtual/gda-ldap-connection.h>
 #include "mgr-ldap-entries.h"
@@ -42,19 +43,6 @@ struct _HierarchyViewPrivate {
 static void hierarchy_view_class_init (HierarchyViewClass *klass);
 static void hierarchy_view_init       (HierarchyView *eview, HierarchyViewClass *klass);
 static void hierarchy_view_dispose   (GObject *object);
-static void hierarchy_view_set_property (GObject *object,
-					 guint param_id,
-					 const GValue *value,
-					 GParamSpec *pspec);
-static void hierarchy_view_get_property (GObject *object,
-					 guint param_id,
-					 GValue *value,
-					 GParamSpec *pspec);
-
-/* properties */
-enum {
-        PROP_0,
-};
 
 static GObjectClass *parent_class = NULL;
 
@@ -70,10 +58,6 @@ hierarchy_view_class_init (HierarchyViewClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	/* Properties */
-        object_class->set_property = hierarchy_view_set_property;
-        object_class->get_property = hierarchy_view_get_property;
-
 	object_class->dispose = hierarchy_view_dispose;
 }
 
@@ -137,36 +121,6 @@ hierarchy_view_get_type (void)
 	return type;
 }
 
-static void
-hierarchy_view_set_property (GObject *object,
-			     guint param_id,
-			     G_GNUC_UNUSED const GValue *value,
-			     GParamSpec *pspec)
-{
-	HierarchyView *eview;
-	eview = HIERARCHY_VIEW (object);
-	switch (param_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
-	}
-}
-
-static void
-hierarchy_view_get_property (GObject *object,
-			     guint param_id,
-			     G_GNUC_UNUSED GValue *value,
-			     GParamSpec *pspec)
-{
-	HierarchyView *eview;
-	eview = HIERARCHY_VIEW (object);
-	switch (param_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
-	}
-}
-
 static gchar *
 hierarchy_view_to_selection (G_GNUC_UNUSED HierarchyView *eview)
 {
@@ -564,7 +518,7 @@ go_to_row (HierarchyView *eview, GtkTreePath *path)
 		else {
 			/* DN not found! */
 			browser_show_message (GTK_WINDOW (gtk_widget_get_toplevel ((GtkWidget*) eview)),
-					      _("Could not find LDAP entry whith DN '%s'"), tofind);
+					      _("Could not find LDAP entry with DN '%s'"), tofind);
 			goto out;
 		}
 	}
