@@ -276,35 +276,41 @@ server_callback (G_GNUC_UNUSED SoupServer *server, SoupMessage *msg,
 		gchar **array = NULL;
 		array = g_strsplit (path, "/", 0);
 		
-		const ConnectionSetting *cs;
-		cs = gda_sql_get_connection (array[0]);
+		if (array) {
+			const ConnectionSetting *cs;
+			cs = gda_sql_get_connection (array[0]);
 		
-		if (cs) {
-			if (msg->method == SOUP_METHOD_GET) {
-				ok = get_for_cnc (webserver, msg, cs, array[1] ? &(array[1]) : NULL, &error);
+			if (cs) {
+				if (msg->method == SOUP_METHOD_GET) {
+					ok = get_for_cnc (webserver, msg, cs, array[1] ? &(array[1]) : NULL, &error);
+					done = TRUE;
+				}
+			}
+			else if (!strcmp (path, "~console")) {
+				get_for_console (webserver, msg);
 				done = TRUE;
 			}
-		}
-		else if (!strcmp (path, "~console")) {
-			get_for_console (webserver, msg);
-			done = TRUE;
-		}
-		else if (!strcmp (path, "~irb")) {
-			ok = get_post_for_irb (webserver, msg, cs, query, &error);
-			done = TRUE;
-		}
-		else if (!strcmp (path, "~cnclist")) {
-			get_for_cnclist (webserver, msg, !auth_needed);
-			done = TRUE;
+			else if (!strcmp (path, "~irb")) {
+				ok = get_post_for_irb (webserver, msg, cs, query, &error);
+				done = TRUE;
+			}
+			else if (!strcmp (path, "~cnclist")) {
+				get_for_cnclist (webserver, msg, !auth_needed);
+				done = TRUE;
+			}
+			else {
+				if (msg->method == SOUP_METHOD_GET) {
+					ok = get_file (webserver, msg, path, &error);
+					done = TRUE;
+				}
+			}
+
+			g_strfreev (array);
 		}
 		else {
-			if (msg->method == SOUP_METHOD_GET) {
-				ok = get_file (webserver, msg, path, &error);
-				done = TRUE;
-			}
+			ok= FALSE;
+			done = TRUE;
 		}
-		if (array)
-			g_strfreev (array);
 	}
 	
 	if (!ok) {
@@ -1989,7 +1995,7 @@ get_post_for_irb (WebServer *webserver, SoupMessage *msg, G_GNUC_UNUSED const Co
 			xmlDocSetRootElement (doc, topnode);
 			
 			xmlNewChild (topnode, NULL, BAD_CAST "cid", BAD_CAST (console->id));
-			tmp = gda_sql_console_compute_prompt (console, OUTPUT_FORMAT_HTML);
+			tmp = gda_sql_console_compute_prompt (console, TOOL_OUTPUT_FORMAT_HTML);
 			xmlNewChild (topnode, NULL, BAD_CAST "prompt", BAD_CAST tmp);
 			g_free (tmp);
 			
@@ -2013,7 +2019,7 @@ get_post_for_irb (WebServer *webserver, SoupMessage *msg, G_GNUC_UNUSED const Co
 		topnode = xmlNewDocNode (doc, NULL, BAD_CAST "result", NULL);
 		xmlDocSetRootElement (doc, topnode);
 
-		tmp = gda_sql_console_execute (console, cmd, &lerror, OUTPUT_FORMAT_HTML);
+		tmp = gda_sql_console_execute (console, cmd, &lerror, TOOL_OUTPUT_FORMAT_HTML);
 		if (!tmp) 
 			tmp = g_strdup_printf (_("Error: %s"), 
 						    lerror && lerror->message ? lerror->message : _("No detail"));
@@ -2023,7 +2029,7 @@ get_post_for_irb (WebServer *webserver, SoupMessage *msg, G_GNUC_UNUSED const Co
 		xmlNewChild (topnode, NULL, BAD_CAST "cmde", BAD_CAST tmp);
 		g_free (tmp);
 
-		tmp = gda_sql_console_compute_prompt (console, OUTPUT_FORMAT_HTML);
+		tmp = gda_sql_console_compute_prompt (console, TOOL_OUTPUT_FORMAT_HTML);
 		xmlNewChild (topnode, NULL, BAD_CAST "prompt", BAD_CAST tmp);
 		g_free (tmp);
 
